;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "lsp-mode" "10.0.0"
  "LSP mode."
  '((emacs         "28.1")
    (dash          "2.18.0")
    (f             "0.21.0")
    (ht            "2.3")
    (spinner       "1.7.3")
    (markdown-mode "2.3")
    (lv            "0")
    (eldoc         "1.11"))
  :url "https://github.com/emacs-lsp/lsp-mode"
  :commit "913a6c07f163205cb568bc68d7dfe677dbc358ab"
  :revdesc "913a6c07f163"
  :keywords '("languages"))
